@@ -7,12 +7,8 @@
 #undef HAVE_LIBSM
 #undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
 #undef HAVE_PROGRAM_INVOCATION_NAME
-#undef HAVE_BONOBO
 
-#undef GNOMECC_ICONS_DIR
-#undef GNOMECC_GLADE_DIR
-#undef GNOMECC_PIXMAPS_DIR
-#undef GNOMECC_SCREENSAVERS_DIR
+#undef GNOMECC_DATA_DIR
 
 #undef PACKAGE
 #undef VERSION
